function dispVariables(varargin)
%DISPVARIABLES despliega valor de variables.
%
%   DISPVARIABLES muestra el valor de todas las variables de tipos soportados
%   definidas en el workspace y sus respectivos valores.
%
%   Se utiliza la funcion "disp" para desplegar los resultados.
%
%   El formato de salida es:
%       (nombreVariable1:valorVariable1, ..., nombreVariableN:valorVariableN)
%
%   Tipos soportados:
%   ^^^^^^^^^^^^^^^^^
%       + Numeric  (entero, punto flotante)
%       + Strings  (cadena de caracteres)
%       + Matrices (Numeric, Strings)
%
%   Tipos no soportados:
%   ^^^^^^^^^^^^^^^^^^^^
%       - Cell
%       - Struct
%       - Object
%       - Function_handle
%       - Java_class

[st,i] = dbstack;
stlen = length(st);
if stlen <= 1
    error('Error: dispVariables debe ejecutarse desde una funcin')
end

functionName = st(2).name;
lineNumber = st(2).line;

true = 1;
false = 0;

varNames = evalin('caller','who');

cantVariables = size(varNames,1);

if nargin == 1 && varargin{1} == 1
    vars = ['Funcin: ' functionName ', Linea: ' int2str(lineNumber) ', Variables: ('];
else
    vars = ['('];
end

firstVarName = false;

for i = 1:cantVariables
    varName = char(varNames(i,1));
    
    if (  ~strcmp(varName,"argn") &&   ~strcmp(varName,"ans")) 
    
        var = evalin('caller',varName);
        
        if ~iscell(var)
            if firstVarName
                vars = [vars ', '];
            end
            
            [rows, cols] = size(var);
            if rows == 0 | cols == 0
                var = '[]';
            else
                var = mat2str (var, 15);
            end
            
            [str errno] = sprintf('%s',var');
            
            if min( size(var) ) ~= 1
                vars = [vars varName ':[' str ']'];
            else
                vars = [vars varName ':' str];
            end
            firstVarName = true;
        else
            firstVarName = true;
        end
    
    end
end

vars = [vars ')'];
disp(vars)